import os.path
from bs4 import BeautifulSoup
import quixote
from quixote import get_context


@quixote.inspector
def inspect():
    def require(cond: bool, fail_message: str):
        if not cond:
            raise AssertionError(fail_message)

    try:
        with open(os.path.join(get_context()["delivery_path"], "index.html"), 'r') as f:
            data = f.read()
    except (OSError, IOError) as e:
        print(e)
        exit(1)

    soup = BeautifulSoup(data, features="html.parser")
    require(soup.title is not None, "No <title> tag found")
    require(soup.title.string.strip() == "My Portfolio", "Incorrect content for the <title> tag")
    require(soup.body is not None, "No <body> tag found")
    body_content = soup.find('body').find_all()
    require(len(body_content) == 1, "Exactly one tag is needed in the body for this exercise")
    h2 = body_content[0]
    require(h2.name == "h2", "The h2 tag should be used for this exercise")
    require(h2.string == "Welcome to my portfolio !", "Incorrect content for the <h2> tag")
    print("OK")
